`timescale 1ns / 1ps

module fifo_tx_tb();

  reg  Clk;
  reg rst;
  reg clk125m_o;
  reg [15:0] din;
  reg wr_en;
  reg rd_en;
  
  wire [7:0] dout;
  wire empty;
  wire full;
  
  wire wr_rst_busy;
  wire rd_rst_busy;
  
  wire [10:0] wr_data_count;
  wire [11:0] rd_data_count;
  
  initial Clk = 1;
  always #10 Clk = ~Clk;
  initial clk125m_o = 1;
  always #4 clk125m_o = ~clk125m_o;
  
  initial begin
    rst = 1'b1;
    wr_en = 1'b0;
    rd_en = 1'b0;
    din = 15'd0;
    
    #201;
    rst = 1'b0;
    @(negedge wr_rst_busy);
    //write data
    while(full == 1'b0)
    begin
        @(posedge Clk);
        #1;
        wr_en = 1'b1;
        din = din + 1'b1;
    end
    wr_en = 1'b0;
    
    wait(rd_rst_busy == 1'b0);
    while(empty == 1'b0)
    begin
        @(posedge clk125m_o);
        #1;
        rd_en = 1'b1;
        end
    rd_en = 1'b0;

    #2000;
    $stop;	
  end
  

  fifo_tx fifo_tx (
      .rst(rst),                      // input wire rst
      .wr_clk(Clk),                // input wire wr_clk
      .rd_clk(clk125m_o),                // input wire rd_clk
      .din(din),                      // input wire [15 : 0] din
      .wr_en(wr_en),                  // input wire wr_en
      .rd_en(rd_en),                  // input wire rd_en
      .dout(dout),                    // output wire [7 : 0] dout
      .full(full),                    // output wire full
      .empty(empty),        // output wire empty
      .wr_data_count(wr_data_count),  // output wire [10 : 0] wr_data_count
      .rd_data_count(rd_data_count),
      .wr_rst_busy(wr_rst_busy),      // output wire wr_rst_busy
      .rd_rst_busy(rd_rst_busy)      // output wire rd_rst_busy
   );

endmodule
